=======
History
=======

0.5.0 (2017-08-12)
------------------

* Adding command line capability

0.4.5 (2017-05-09)
------------------

* Returning rank of the given host rather than just a boolean
* Adding (better) codecoverage when testing

0.4.1 (2017-04-25)
------------------

* Improving comments and documentation
* Separating the list updating from the domain check

0.4.0 (2017-04-12)
------------------

* Improved testing

0.1.0 (2017-04-04)
------------------

* First release on PyPI.
